@@ -6,12 +6,12 @@ BEGIN {
   $B::Hooks::EndOfScope::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $B::Hooks::EndOfScope::VERSION = '0.10';
+  $B::Hooks::EndOfScope::VERSION = '0.11';
 }
 # ABSTRACT: Execute code after a scope finished compilation
 
 use 5.008000;
-use Variable::Magic 0.34;
+use Variable::Magic 0.48;
 
 use Sub::Exporter -setup => {
     exports => ['on_scope_end'],
@@ -26,11 +26,11 @@ use Sub::Exporter -setup => {
         free => sub { $_->() for @{ $_[1] }; () },
         # When someone localise %^H, our magic doesn't want to be copied
         # down. We want it to be around only for the scope we've initially
-        # attached ourselfs to. Merely having an svt_local callback achieves
-        # this. If anything wants to attach more magic of our kind to a
-        # localised %^H, things will continue to just work as we'll be attached
-        # with a new and empty callback list.
-        local => sub { () };
+        # attached ourselfs to. Merely having MGf_LOCAL and a noop svt_local
+        # callback achieves this. If anything wants to attach more magic of our
+        # kind to a localised %^H, things will continue to just work as we'll be
+        # attached with a new and empty callback list.
+        local => \undef;
 
     sub on_scope_end (&) {
         my $cb = shift;
